This selected probe sets information contains the sequence of the selected probe sets, as well as the match and mismatch onformation and Delta G value required for the langmuir analysis
Usage
data(hgu)
Arguments
Format
A data frame with 11452 observations on the following 9 variables.