Learn R Programming

spikeLI (version 2.32.0)

spikeLI-package: Analysis of Affymetrix spike-in data (HGU95 and HGU133 Latin square) using the Langmuir Isotherm.

Description

spikeLI performs a series of analysis of Affymetrix spike-in data using inputs from physical-chemistry. It illustrates the advantages of such approach in determining expression levels and in identifying outliers compared to other methods. The analysis so far is restricted to spike-in genes. It will be extended to a generic CEL file. spikeLI does not require affy (and it is independent of any other bioconductor packages) as it reads spike-in data from a data frame variable hgu which is contained in the package.

Arguments

Details

Package:
spikeLI
Type:
Package
Version:
1.0
Date:
2006-05-05
License:
GNU Public License
The package contains three basic functions: - Ivsc plot intensities as function of spike-in concentration for a fixed probe. - IvsDG plot intensities as function of affinity for a given probe set at fixed concentration. - collapse plot of intensities both as a function of concentration and affinities.

References

E. Carlon and T. Heim, Physica A 362, 433 (2006).

See Also

collapse, Ivsc, IvsDG, hgu, SPIKE_IN, SPIKE_INA, SPIKE_INB, SPIKE_INH , SPIKE_IN95